# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import metal_python
from metal_python.models.v1_size_response import V1SizeResponse  # noqa: E501
from metal_python.rest import ApiException


class TestV1SizeResponse(unittest.TestCase):
    """V1SizeResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testV1SizeResponse(self):
        """Test V1SizeResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = metal_python.models.v1_size_response.V1SizeResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
